==> react-native-web-material-0.4.2.tgz: package/docs/components/Button.js <==
import React from 'react';
import { StyleSheet, View } from 'react-native';
import { Button } from '../../src/';

const styles = StyleSheet.create({
  section: {
    flexDirection: 'row',
    padding: 24,
  },
  list: {
    alignItems: 'center',
    flex: 1,
    flexDirection: 'row',
    flexWrap: 'wrap',
  },
  item: {
    margin: 16,
  },
});

export default function (storiesOf) {
  storiesOf('Button', module)
    .addDecorator(story => <View style={styles.section}>{story()}</View>)
    .add('Text Button', () => (
      <View style={styles.list}>
        <View style={styles.item}>
          <Button title="Baseline" />
        </View>
        <View style={styles.item}>
          <Button title="Compact" compact />
        </View>
        <View style={styles.item}>
          <Button title="Dense" dense />
        </View>
        <View style={styles.item}>
          <Button title="Primary" primary />
        </View>
        <View style={styles.item}>
          <Button title="Secondary" secondary />
        </View>
        <View style={styles.item}>
          <Button title="Link" href="/" />
        </View>
      </View>
    ))
    .add('Raised Button', () => (
      <View style={styles.list}>
        <View style={styles.item}>
          <Button raised title="Baseline" />
        </View>
        <View style={styles.item}>
          <Button raised title="Compact" compact />
        </View>
        <View style={styles.item}>
          <Button raised title="Dense" dense />
        </View>
        <View style={styles.item}>
          <Button raised title="Primary" primary />
        </View>
        <View style={styles.item}>
          <Button raised title="Secondary" secondary />
        </View>
        <View style={styles.item}>
          <Button raised title="Link" href="/" />
        </View>
      </View>
    ));
}

==> react-native-web-material-0.5.3.tgz: package/docs/components/Button.js <==
// @flow
import React from 'react';
// $FlowFixMe
import { StyleSheet, View } from 'react-native';
import type { storiesOf as StoriesOf } from '@storybook/react';
import { Button } from '../../src/';

const styles = StyleSheet.create({
  section: {
    flexDirection: 'row',
    padding: 24,
  },
  list: {
    alignItems: 'center',
    flex: 1,
    flexDirection: 'row',
    flexWrap: 'wrap',
  },
  item: {
    margin: 16,
  },
});

export default function (storiesOf: StoriesOf) {
  storiesOf('Button', module)
    .addDecorator(story => <View style={styles.section}>{story()}</View>)
    .add('Text Button', () => (
      <View style={styles.list}>
        <View style={styles.item}>
          <Button title="Baseline" />
        </View>
        <View style={styles.item}>
          <Button title="Compact" compact />
        </View>
        <View style={styles.item}>
          <Button title="Dense" dense />
        </View>
        <View style={styles.item}>
          <Button title="Primary" primary />
        </View>
        <View style={styles.item}>
          <Button title="Secondary" secondary />
        </View>
        <View style={styles.item}>
          <Button title="Link" href="/" />
        </View>
      </View>
    ))
    .add('Raised Button', () => (
      <View style={styles.list}>
        <View style={styles.item}>
          <Button raised title="Baseline" />
        </View>
        <View style={styles.item}>
          <Button raised title="Compact" compact />
        </View>
        <View style={styles.item}>
          <Button raised title="Dense" dense />
        </View>
        <View style={styles.item}>
          <Button raised title="Primary" primary />
        </View>
        <View style={styles.item}>
          <Button raised title="Secondary" secondary />
        </View>
        <View style={styles.item}>
          <Button raised title="Link" href="/" />
        </View>
      </View>
    ));
}
